@@ -3,11 +3,15 @@ from auto_everything.terminal import Terminal
 from auto_everything.disk import Disk
 from auto_everything.python import Python
 from auto_everything.network import Network
+from auto_everything.cryptography import EncryptionAndDecryption
+from auto_everything.develop import YRPC
 
 __all__ = [
     'IO',
     'Terminal',
     'Disk',
     'Python',
-    'Network'
+    'Network',
+    'EncryptionAndDecryption',
+    'YRPC'
 ]
\ No newline at end of file
